================================
Create a Tackle Box From Scratch
================================

Step 1: Name Your Tackle
------------------------------

In this tutorial, we are creating *tackle-website-simple*, a tackle
for generating simple, bare-bones websites.

Create the directory for your tackle box and cd into it:

.. code-block:: bash

    $ mkdir tackle-website-simple
    $ cd tackle-website-simple/

Step 2: Create `project_slug` Directory
---------------------------------------

Create a directory called `{{ project_slug }}`.

This value will be replaced with the repo name of projects that you generate
from this cookiecutter.

Step 3: Create Files
--------------------

Inside of `{{ project_slug }}`, create `index.html`, `site.css`, and
`site.js`.

To be continued...
